@@ -51,10 +51,10 @@
 /* BOOLEAN:BOXED (gs-theme-engine-marshal.list:1) */
 void
 gs_theme_engine_marshal_BOOLEAN__BOXED (GClosure     *closure,
-                                        GValue       *return_value,
+                                        GValue       *return_value G_GNUC_UNUSED,
                                         guint         n_param_values,
                                         const GValue *param_values,
-                                        gpointer      invocation_hint,
+                                        gpointer      invocation_hint G_GNUC_UNUSED,
                                         gpointer      marshal_data)
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__BOXED) (gpointer     data1,
