@@ -38,12 +38,34 @@ G_BEGIN_DECLS
 
 void gs_debug_init             (gboolean debug,
                                 gboolean to_file);
+gboolean gs_debug_enabled      (void);
 void gs_debug_shutdown         (void);
 void gs_debug_real             (const char *func,
                                 const char *file,
                                 int         line,
                                 const char *format, ...);
 
+#ifdef ENABLE_PROFILING
+#ifdef G_HAVE_ISO_VARARGS
+#define gs_profile_start(...) _gs_profile_log (G_STRFUNC, "start", __VA_ARGS__)
+#define gs_profile_end(...)   _gs_profile_log (G_STRFUNC, "end", __VA_ARGS__)
+#define gs_profile_msg(...)   _gs_profile_log (NULL, NULL, __VA_ARGS__)
+#elif defined(G_HAVE_GNUC_VARARGS)
+#define gs_profile_start(format...) _gs_profile_log (G_STRFUNC, "start", format)
+#define gs_profile_end(format...)   _gs_profile_log (G_STRFUNC, "end", format)
+#define gs_profile_msg(format...)   _gs_profile_log (NULL, NULL, format)
+#endif
+#else
+#define gs_profile_start(...)
+#define gs_profile_end(...)
+#define gs_profile_msg(...)
+#endif
+
+void            _gs_profile_log    (const char *func,
+                                    const char *note,
+                                    const char *format,
+                                    ...) G_GNUC_PRINTF (3, 4);
+
 G_END_DECLS
 
 #endif /* __GS_DEBUG_H */
