@@ -112,7 +112,7 @@ wait_on_child (int pid)
                 } else if (errno == ECHILD) {
                         ; /* do nothing, child already reaped */
                 } else {
-                        g_warning ("waitpid () should not fail in 'GSJob'");
+                        gs_debug ("waitpid () should not fail in 'GSJob'");
                 }
         }
 
@@ -189,6 +189,9 @@ gs_job_set_command  (GSJob      *job,
 {
         g_return_val_if_fail (GS_IS_JOB (job), FALSE);
 
+        gs_debug ("Setting command for job: '%s'",
+                  command != NULL ? command : "NULL");
+
         g_free (job->priv->command);
         job->priv->command = g_strdup (command);
 
@@ -230,11 +233,11 @@ nice_process (int pid,
 #if defined(HAVE_SETPRIORITY) && defined(PRIO_PROCESS)
         gs_debug ("Setting child process priority to: %d", nice_level);
         if (setpriority (PRIO_PROCESS, pid, nice_level) != 0) {
-                g_warning ("setpriority(PRIO_PROCESS, %lu, %d) failed",
-                           (unsigned long) pid, nice_level);
+                gs_debug ("setpriority(PRIO_PROCESS, %lu, %d) failed",
+                          (unsigned long) pid, nice_level);
         }
 #else
-        g_warning ("don't know how to change process priority on this system.");
+        gs_debug ("don't know how to change process priority on this system.");
 #endif
 }
 
@@ -250,7 +253,8 @@ get_env_vars (GtkWidget *widget)
                 "XAUTHORITY",
                 "XAUTHLOCALHOSTNAME",
                 "LANG",
-                "LANGUAGE"
+                "LANGUAGE",
+                "DBUS_SESSION_BUS_ADDRESS"
         };
 
         env = g_ptr_array_new ();
@@ -306,7 +310,7 @@ spawn_on_widget (GtkWidget  *widget,
         }
 
         if (! g_shell_parse_argv (command, NULL, &argv, &error)) {
-                g_warning ("Could not parse command: %s", error->message);
+                gs_debug ("Could not parse command: %s", error->message);
                 g_error_free (error);
                 return FALSE;
         }
@@ -332,7 +336,7 @@ spawn_on_widget (GtkWidget  *widget,
         g_ptr_array_free (env, TRUE);
 
         if (! result) {
-                g_warning ("Could not start command '%s': %s", command, error->message);
+                gs_debug ("Could not start command '%s': %s", command, error->message);
                 g_error_free (error);
                 g_strfreev (argv);
                 return FALSE;
@@ -382,12 +386,16 @@ command_watch (GIOChannel   *source,
 
                 status = g_io_channel_read_line (source, &str, NULL, NULL, &error);
 
-		if (status == G_IO_STATUS_NORMAL) {
+                if (status == G_IO_STATUS_NORMAL) {
                         gs_debug ("command output: %s", str);
 
-		} else if (status == G_IO_STATUS_EOF) {
+                } else if (status == G_IO_STATUS_EOF) {
                         done = TRUE;
-		}
+
+                } else if (error != NULL) {
+                        gs_debug ("command error: %s", error->message);
+                        g_error_free (error);
+                }
 
                 g_free (str);
         } else if (condition & G_IO_HUP) {
@@ -427,18 +435,19 @@ gs_job_start (GSJob *job)
         gs_debug ("starting job");
 
         if (job->priv->pid != 0) {
-                g_warning ("Cannot restart active job.");
+                gs_debug ("Cannot restart active job.");
                 return FALSE;
         }
 
         if (job->priv->widget == NULL) {
-                g_warning ("Could not start job: screensaver window is not set.");
+                gs_debug ("Could not start job: screensaver window is not set.");
                 return FALSE;
         }
 
         if (job->priv->command == NULL) {
                 /* no warning here because a NULL command is interpreted
                    as a no-op job */
+                gs_debug ("No command set for job.");
                 return FALSE;
         }
 
