@@ -55,18 +55,11 @@ struct GSMonitorPrivate
         GSPrefs        *prefs;
         GSFade         *fade;
         GSGrab         *grab;
-
         guint           release_grab_id;
 };
 
-enum {
-        PROP_0
-};
-
 #define FADE_TIMEOUT 10000
 
-static GObjectClass *parent_class = NULL;
-
 G_DEFINE_TYPE (GSMonitor, gs_monitor, G_TYPE_OBJECT)
 
 static void
@@ -74,8 +67,6 @@ gs_monitor_class_init (GSMonitorClass *klass)
 {
         GObjectClass   *object_class = G_OBJECT_CLASS (klass);
 
-        parent_class = g_type_class_peek_parent (klass);
-
         object_class->finalize = gs_monitor_finalize;
 
         g_type_class_add_private (klass, sizeof (GSMonitorPrivate));
@@ -94,20 +85,6 @@ manager_deactivated_cb (GSManager *manager,
         gs_listener_set_active (monitor->priv->listener, FALSE);
 }
 
-static void
-manager_auth_request_begin_cb (GSManager *manager,
-                               GSMonitor *monitor)
-{
-        gs_listener_emit_auth_request_begin (monitor->priv->listener);
-}
-
-static void
-manager_auth_request_end_cb (GSManager *manager,
-                             GSMonitor *monitor)
-{
-        gs_listener_emit_auth_request_end (monitor->priv->listener);
-}
-
 static gboolean
 watcher_idle_cb (GSWatcher *watcher,
                  gboolean   is_idle,
@@ -188,8 +165,7 @@ watcher_idle_notice_cb (GSWatcher *watcher,
 }
 
 static void
-listener_lock_cb (GSListener *listener,
-                  GSMonitor  *monitor)
+gs_monitor_lock_screen (GSMonitor *monitor)
 {
         gboolean res;
         gboolean locked;
@@ -207,6 +183,28 @@ listener_lock_cb (GSListener *listener,
         }
 }
 
+static void
+gs_monitor_simulate_user_activity (GSMonitor *monitor)
+{
+        /* FIXME: reset the xsync timer? */
+
+        /* request that the manager unlock -
+           will pop up a dialog if necessary */
+        gs_manager_request_unlock (monitor->priv->manager);
+}
+
+static void
+listener_lock_cb (GSListener *listener,
+                  GSMonitor  *monitor)
+{
+        if (! monitor->priv->prefs->lock_disabled) {
+                gs_monitor_lock_screen (monitor);
+        } else {
+                gs_debug ("Locking disabled by the administrator");
+        }
+
+}
+
 static void
 listener_quit_cb (GSListener *listener,
                   GSMonitor  *monitor)
@@ -265,13 +263,7 @@ static void
 listener_simulate_user_activity_cb (GSListener *listener,
                                     GSMonitor  *monitor)
 {
-        /* in case the screen isn't blanked reset the
-           idle watcher */
-        gs_watcher_reset (monitor->priv->watcher);
-
-        /* request that the manager unlock -
-           will pop up a dialog if necessary */
-        gs_manager_request_unlock (monitor->priv->manager);
+        gs_monitor_simulate_user_activity (monitor);
 }
 
 static void
@@ -282,13 +274,20 @@ _gs_monitor_update_from_prefs (GSMonitor *monitor,
         gboolean idle_detection_active;
         gboolean activate_watch;
         gboolean manager_active;
+        gboolean lock_enabled;
+        gboolean user_switch_enabled;
 
-        gs_manager_set_lock_enabled (monitor->priv->manager, monitor->priv->prefs->lock_enabled);
+        lock_enabled = (monitor->priv->prefs->lock_enabled && !monitor->priv->prefs->lock_disabled);
+        user_switch_enabled = (monitor->priv->prefs->user_switch_enabled && !monitor->priv->prefs->user_switch_disabled);
+
+        gs_manager_set_lock_enabled (monitor->priv->manager, lock_enabled);
         gs_manager_set_lock_timeout (monitor->priv->manager, monitor->priv->prefs->lock_timeout);
         gs_manager_set_logout_enabled (monitor->priv->manager, monitor->priv->prefs->logout_enabled);
-        gs_manager_set_user_switch_enabled (monitor->priv->manager, monitor->priv->prefs->user_switch_enabled);
+        gs_manager_set_user_switch_enabled (monitor->priv->manager, user_switch_enabled);
+        gs_manager_set_keyboard_enabled (monitor->priv->manager, monitor->priv->prefs->keyboard_enabled);
         gs_manager_set_logout_timeout (monitor->priv->manager, monitor->priv->prefs->logout_timeout);
         gs_manager_set_logout_command (monitor->priv->manager, monitor->priv->prefs->logout_command);
+        gs_manager_set_keyboard_command (monitor->priv->manager, monitor->priv->prefs->keyboard_command);
         gs_manager_set_cycle_timeout (monitor->priv->manager, monitor->priv->prefs->cycle);
         gs_manager_set_mode (monitor->priv->manager, monitor->priv->prefs->mode);
         gs_manager_set_themes (monitor->priv->manager, monitor->priv->prefs->themes);
@@ -300,7 +299,6 @@ _gs_monitor_update_from_prefs (GSMonitor *monitor,
         /* idle detection always enabled */
         idle_detection_enabled = TRUE;
 
-        gs_watcher_set_timeout (monitor->priv->watcher, monitor->priv->prefs->timeout);
         gs_watcher_set_enabled (monitor->priv->watcher, idle_detection_enabled);
 
         /* in the case where idle detection is reenabled we may need to
@@ -314,6 +312,17 @@ _gs_monitor_update_from_prefs (GSMonitor *monitor,
         if (activate_watch) {
                 gs_watcher_set_active (monitor->priv->watcher, TRUE);
         }
+
+        if (monitor->priv->prefs->status_message_enabled) {
+                char *text;
+                g_object_get (monitor->priv->watcher,
+                              "status-message", &text,
+                              NULL);
+                gs_manager_set_status_message (monitor->priv->manager, text);
+                g_free (text);
+        } else {
+                gs_manager_set_status_message (monitor->priv->manager, NULL);
+        }
 }
 
 static void
@@ -344,20 +353,35 @@ connect_listener_signals (GSMonitor *monitor)
                           G_CALLBACK (listener_simulate_user_activity_cb), monitor);
 }
 
+static void
+on_watcher_status_message_changed (GSWatcher  *watcher,
+                                   GParamSpec *pspec,
+                                   GSMonitor  *monitor)
+{
+        char *text;
+        g_object_get (watcher, "status-message", &text, NULL);
+        gs_manager_set_status_message (monitor->priv->manager, text);
+        g_free (text);
+}
+
 static void
 disconnect_watcher_signals (GSMonitor *monitor)
 {
         g_signal_handlers_disconnect_by_func (monitor->priv->watcher, watcher_idle_cb, monitor);
         g_signal_handlers_disconnect_by_func (monitor->priv->watcher, watcher_idle_notice_cb, monitor);
+        g_signal_handlers_disconnect_by_func (monitor->priv->watcher, on_watcher_status_message_changed, monitor);
 }
 
 static void
 connect_watcher_signals (GSMonitor *monitor)
 {
-        g_signal_connect (monitor->priv->watcher, "idle_changed",
+        g_signal_connect (monitor->priv->watcher, "idle-changed",
                           G_CALLBACK (watcher_idle_cb), monitor);
-        g_signal_connect (monitor->priv->watcher, "idle_notice_changed",
+        g_signal_connect (monitor->priv->watcher, "idle-notice-changed",
                           G_CALLBACK (watcher_idle_notice_cb), monitor);
+        g_signal_connect (monitor->priv->watcher, "notify::status-message",
+                          G_CALLBACK (on_watcher_status_message_changed), monitor);
+
 }
 
 static void
@@ -365,8 +389,6 @@ disconnect_manager_signals (GSMonitor *monitor)
 {
         g_signal_handlers_disconnect_by_func (monitor->priv->manager, manager_activated_cb, monitor);
         g_signal_handlers_disconnect_by_func (monitor->priv->manager, manager_deactivated_cb, monitor);
-        g_signal_handlers_disconnect_by_func (monitor->priv->manager, manager_auth_request_begin_cb, monitor);
-        g_signal_handlers_disconnect_by_func (monitor->priv->manager, manager_auth_request_end_cb, monitor);
 }
 
 static void
@@ -376,10 +398,6 @@ connect_manager_signals (GSMonitor *monitor)
                           G_CALLBACK (manager_activated_cb), monitor);
         g_signal_connect (monitor->priv->manager, "deactivated",
                           G_CALLBACK (manager_deactivated_cb), monitor);
-        g_signal_connect (monitor->priv->manager, "auth-request-begin",
-                          G_CALLBACK (manager_auth_request_begin_cb), monitor);
-        g_signal_connect (monitor->priv->manager, "auth-request-end",
-                          G_CALLBACK (manager_auth_request_end_cb), monitor);
 }
 
 static void
@@ -410,7 +428,7 @@ gs_monitor_init (GSMonitor *monitor)
         monitor->priv->fade = gs_fade_new ();
         monitor->priv->grab = gs_grab_new ();
 
-        monitor->priv->watcher = gs_watcher_new (monitor->priv->prefs->timeout);
+        monitor->priv->watcher = gs_watcher_new ();
         connect_watcher_signals (monitor);
 
         monitor->priv->manager = gs_manager_new ();
@@ -443,7 +461,7 @@ gs_monitor_finalize (GObject *object)
         g_object_unref (monitor->priv->manager);
         g_object_unref (monitor->priv->prefs);
 
-        G_OBJECT_CLASS (parent_class)->finalize (object);
+        G_OBJECT_CLASS (gs_monitor_parent_class)->finalize (object);
 }
 
 GSMonitor *
